@@ -20,11 +20,8 @@
 #define __IO_CLIENT_HANDLER__
 
 #include <boost/bind.hpp>
-#include <boost/thread.hpp>
-#include <boost/utility.hpp>
 #include <asio.hpp>
 
-#include "IOServiceThread.h" 
 #include "Synchronizer.h"
 #include "Session.h"
 #include "IOHandler.h"
@@ -69,7 +66,7 @@ public:
 		UT_return_if_fail(work == NULL);
 		
 		work = new asio::io_service::work(io_service);
-		thread = new boost::thread(IOServiceThread(io_service));
+		thread = new asio::thread(boost::bind(&asio::io_service::run, &io_service));
 		
 		// TODO: catch exceptions
 		asio::ip::tcp::resolver::iterator iterator(resolver.resolve(query));
@@ -79,7 +76,7 @@ public:
 
 private:
 	asio::io_service					io_service;
-	boost::thread*						thread;
+	asio::thread*						thread;
 	asio::io_service::work*				work;
 	asio::ip::tcp::resolver				resolver;
 	asio::ip::tcp::resolver::query		query;
