@@ -20,6 +20,7 @@
 #define __SESSION__
 
 #include <deque>
+#include <backends/xp/lock.h>
 
 class TCPAccountHandler;
 
@@ -37,7 +38,15 @@ public:
 	virtual ~Session()
 	{
 		UT_DEBUGMSG(("~Session()\n"));
-		socket.close();
+		asio::error_code ecs;
+		socket.shutdown(asio::ip::tcp::socket::shutdown_both, ecs);
+		if (ecs)
+			UT_DEBUGMSG(("Error shutting down socket: %s\n", ecs.message().c_str()));
+
+		asio::error_code ecc;
+		socket.close(ecc);
+		if (ecc)
+			UT_DEBUGMSG(("Error closing socket: %s\n", ecc.message().c_str()));
 	}
 
 	asio::ip::tcp::socket& getSocket()
@@ -48,7 +57,7 @@ public:
 	void push(int size, char* data)
 	{
 		{
-			boost::mutex::scoped_lock lock(queue_protector); 
+			abicollab::scoped_lock lock(queue_protector); 
 			incoming.push_back( std::pair<int, char*>(size, data) );
 		}
 		signal();
@@ -62,7 +71,7 @@ public:
 		if (incoming.size() == 0)
 			return false;
 		{
-			boost::mutex::scoped_lock lock(queue_protector); 
+			abicollab::scoped_lock lock(queue_protector); 
 			std::pair<int, char*> p = incoming.front();
 			size = p.first;
 			*data = p.second;
@@ -218,7 +227,7 @@ private:
 	}
 
 	asio::ip::tcp::socket					socket;
-	boost::mutex 							queue_protector;
+	abicollab::mutex 							queue_protector;
 	std::deque< std::pair<int, char*> >		incoming;
 	std::deque< std::pair<int, char*> >		outgoing;
 
