@@ -1,4 +1,4 @@
-/* Copyright (C) 2006,2007 by Marc Maurer <uwog@uwog.net>
+/* Copyright (C) 2006-2008 by Marc Maurer <uwog@uwog.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,6 +50,7 @@ TCPAccountHandler::TCPAccountHandler()
 
 TCPAccountHandler::~TCPAccountHandler()
 {
+	UT_DEBUGMSG(("~TCPAccountHandler()\n"));
 	if (m_bConnected)
 		disconnect();
 }
@@ -86,6 +87,7 @@ ConnectResult TCPAccountHandler::connect()
 	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
 	UT_return_val_if_fail(pManager, CONNECT_INTERNAL_ERROR);
 
+	UT_return_val_if_fail(!m_pDelegator, CONNECT_INTERNAL_ERROR);
 	
 	if (m_bConnected)
 		return CONNECT_ALREADY_CONNECTED;
@@ -96,7 +98,6 @@ ConnectResult TCPAccountHandler::connect()
 		UT_sint32 port = _getPort(getProperties());
 		UT_DEBUGMSG(("Start accepting connections on port %d...\n", port));
 
-		// TODO: do we catch all possible acceptions?
 		try
 		{
 			IOServerHandler* pDelegator = new IOServerHandler(port, IOAcceptFunc, *this);
@@ -105,12 +106,19 @@ ConnectResult TCPAccountHandler::connect()
 
 			m_pPendingSession = pDelegator->constructSession(IOEventFunc, *this);
 			pDelegator->run(*m_pPendingSession);
-		} catch (asio::system_error se)
+		}
+		catch (asio::system_error se)
 		{
 			UT_DEBUGMSG(("Failed to start accepting connections: %s\n", se.what()));
 			_teardownAndDestroyHandler();
 			return CONNECT_FAILED;
 		}
+		catch (...)
+		{
+			UT_DEBUGMSG(("Caught unhandled server exception!\n"));
+			_teardownAndDestroyHandler();
+			return CONNECT_FAILED;
+		}
 	}
 	else
 	{
@@ -143,17 +151,23 @@ ConnectResult TCPAccountHandler::connect()
 			_teardownAndDestroyHandler();
 			return CONNECT_FAILED;
 		}
+		catch (...)
+		{
+			UT_DEBUGMSG(("Caught unhandled client exception!\n"));
+			_teardownAndDestroyHandler();
+			return CONNECT_FAILED;
+		}		
 	}
 	
-	if (m_bConnected)
-	{
-		// we are connected now, time to start sending out messages (such as events)
-		pManager->registerEventListener(this);
-		// signal all listeners we are logged in
-		AccountOnlineEvent event;
-		// TODO: fill the event
-		AbiCollabSessionManager::getManager()->signal(event);
-	}
+	if (!m_bConnected)
+		return CONNECT_FAILED;
+
+	// we are connected now, time to start sending out messages (such as events)
+	pManager->registerEventListener(this);
+	// signal all listeners we are logged in
+	AccountOnlineEvent event;
+	// TODO: fill the event
+	AbiCollabSessionManager::getManager()->signal(event);
 
 	return CONNECT_SUCCESS;
 }
@@ -183,20 +197,20 @@ void TCPAccountHandler::_teardownAndDestroyHandler()
 {
 	UT_return_if_fail(m_pDelegator);
 
-	// first, stop the IO handler
-	m_pDelegator->stop();
-
-	// ... then destroy the pending client session (if any) (ugly)
+	// stop accepting new connections
+	UT_DEBUGMSG(("Stop accepting connections\n"));
 	if (m_pPendingSession)
 		DELETEP(m_pPendingSession);
 
 	// ... then tear down all client connections
+	UT_DEBUGMSG(("Tearing down client connections\n"));
 	for (std::map<const TCPBuddy*, Session*>::iterator it = m_clients.begin(); it != m_clients.end();)
 	{
 		std::map<const TCPBuddy*, Session*>::iterator next_it = it;
 		next_it++;
 
 		// const TCPBuddy* pBuddy = (*it).first;
+		// TODO: remove this buddy from all running sessions
 		// TODO: signal the buddy leaving && free the buddy
 
 		Session* pSession = (*it).second;
@@ -206,10 +220,38 @@ void TCPAccountHandler::_teardownAndDestroyHandler()
 		it = next_it;
 	}
 
-	// ... and then kill off the IO handler alltogether
+	// ... then stop the IO handler
+	UT_DEBUGMSG(("Stopping the IO handler\n"));
+	m_pDelegator->stop();
+
+	// ... and finally kill off the IO handler alltogether
+	UT_DEBUGMSG(("Deleting the IO handler\n"));
 	DELETEP(m_pDelegator);
 }
 
+void TCPAccountHandler::_handleMessages(Session& session)
+{
+	UT_DEBUGMSG(("TCPAccountHandler::_handleMessages()\n"));
+	
+	// handle all packets waiting in our queue
+	int packet_size;
+	char* packet_data;
+	while (session.pop(packet_size, &packet_data))
+	{
+		// setup raw packet struct
+		RawPacket pRp;
+		pRp.buddy = const_cast<TCPBuddy*>(_getBuddy(&session));
+		pRp.packet.resize( packet_size );
+		memcpy( &pRp.packet[0], packet_data, packet_size );
+		
+		// cleanup packet
+		FREEP(packet_data);
+		
+		// handle!
+		handleMessage( pRp );
+	}	
+}
+
 bool TCPAccountHandler::isOnline()
 {
 	return m_bConnected; // TODO: ask the IO handler
@@ -299,40 +341,50 @@ void TCPAccountHandler::forceDisconnectBuddy(Buddy* buddy)
 void TCPAccountHandler::handleEvent(Session& session)
 {
 	UT_DEBUGMSG(("TCPAccountHandler::handleEvent()\n"));
-	
-	// get an incoming packet, if any
-	// TODO: we could read all packets here in one go
-	int packet_size;
-	char* packet_data;
-	if (session.pop(packet_size, &packet_data))
-	{
-		/*
-		printf("Got packet:\n");
-		for (int i = 0; i < packet_size; i++)
-		{
-			printf("%02x ", (UT_uint8)packet_data[i] );
-		}
-		printf("\n");
-		*/
-		
-		// setup raw packet struct
-		RawPacket pRp;
-		pRp.buddy = const_cast<TCPBuddy*>(_getBuddy(&session));
-		pRp.packet.resize( packet_size );
-		memcpy( &pRp.packet[0], packet_data, packet_size );
-		
-		// cleanup packet
-		FREEP(packet_data);
-		
-		// handle!
-		handleMessage( pRp );
-	}
 
+	AbiCollabSessionManager* pManager = AbiCollabSessionManager::getManager();
+	UT_return_if_fail(pManager);
+
+	// make sure we have handled _all_ packets in the queue before checking
+	// the disconnected status
+	bool disconnected = !session.isConnected();
+	_handleMessages(session);
+	
 	// check the connection status
-	if (!session.isConnected())
+	if (disconnected)
 	{
-		UT_DEBUGMSG(("Socket is not connected anymore!!!!!\n"));
-		// FIXME: handle this (delete the session, and remove it from the client list)
+		UT_DEBUGMSG(("Socket is not connected anymore!\n"));
+		// drop all buddies that were on this connection
+		std::map<const TCPBuddy*, Session*>::iterator next;
+		for (std::map<const TCPBuddy*, Session*>::iterator it = m_clients.begin(); it != m_clients.end(); it = next)
+		{
+			next = it;
+			next++;
+		
+			UT_continue_if_fail((*it).first);
+			UT_continue_if_fail((*it).second);
+
+			const TCPBuddy* pB = (*it).first;
+			const Session* pS = (*it).second;
+			
+			if (pS == &session)
+			{
+				UT_DEBUGMSG(("Lost connection to %s buddy %s\n", getProperty("server") == "" ? "client" : "server", pB->getName().utf8_str()));
+				// drop this buddy from all sessions
+				pManager->removeBuddy(pB, false);
+				
+				// erase the buddy <-> session mapping
+				m_clients.erase(it);
+			}
+
+			// if we were connected to a server, then we are disconnected now
+			if (getProperty("server") != "")
+			{
+				UT_ASSERT_HARMLESS(next == m_clients.end());
+				disconnect();
+				break;
+			}
+		}
 	}
 
 	// check other things here if needed...
