@@ -1,4 +1,4 @@
-/* Copyright (C) 2006,2007 by Marc Maurer <uwog@uwog.net>
+/* Copyright (C) 2006-2008 by Marc Maurer <uwog@uwog.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 
 class TCPBuddy;
 
-#define DEFAULT_TCP_PORT 58599  /* e * 10^4 + pi * 10^4 */
+#define DEFAULT_TCP_PORT 25509  /* log2(e + pi) * 10^4 */
 
 extern AccountHandlerConstructor TCPAccountHandlerConstructor;
 
@@ -73,6 +73,7 @@ protected:
 	
 private:
 	void									_teardownAndDestroyHandler();
+	void									_handleMessages(Session& session);
 		
 	bool									m_bConnected; // TODO: drop this, ask the IO handler
 	IOHandler*								m_pDelegator;
