@@ -28,10 +28,10 @@
 class ABI_EXPORT EventPacket : public Packet
 {
 public:
+	DECLARE_ABSTRACT_PACKET(EventPacket);
+	
 	virtual PacketType getType() const
 		{ return PT_Event; }
-		
-	virtual PacketEventType getEventType() const = 0;
 };
 
 #endif /* __EVENTPACKET_H__ */
