@@ -83,8 +83,11 @@ static XAP_Menu_Id loadBindingID;
 static XAP_Menu_Id dumpEditMethodsID;
 static XAP_Menu_Id saveBindingID;
 static const char * szLoadBinding = "Load keybindings";
+static const char * szLoadBindingStatus = "Load keybindings from a file";
 static const char * szDumpEditMethods = "Dump edit methods";
+static const char * szDumpEditMethodsStatus = "Dump edit methods to your console";
 static const char * szSaveBinding = "Save keybindings";
+static const char * szSaveBindingStatus = "Save keybindings to your profile directory";
 
 static void LoadBindings_registerMethod () 
 {
@@ -113,7 +116,7 @@ static void LoadBindings_registerMethod ()
 #if defined(DEBUG)
 	// add menu item
 	loadBindingID = pFact->addNewMenuAfter("Main",NULL,AP_MENU_ID_FMT_STYLIST,EV_MLF_Normal);	// named _FMT_, but actually in tools menu
-	pFact->addNewLabel(NULL,loadBindingID,szLoadBinding, NULL);
+	pFact->addNewLabel(NULL,loadBindingID,szLoadBinding,szLoadBindingStatus);
 	EV_Menu_Action* myLoadBindingAction = new EV_Menu_Action(
 		loadBindingID,          // id that the layout said we could use
 		0,                      // no, we don't have a sub menu.
@@ -128,7 +131,7 @@ static void LoadBindings_registerMethod ()
 	
 	// add menu item
 	dumpEditMethodsID = pFact->addNewMenuAfter("Main",NULL,loadBindingID,EV_MLF_Normal);
-	pFact->addNewLabel(NULL,dumpEditMethodsID,szDumpEditMethods, NULL);
+	pFact->addNewLabel(NULL,dumpEditMethodsID,szDumpEditMethods,szDumpEditMethodsStatus);
 	EV_Menu_Action* myDumpEditMethodsAction = new EV_Menu_Action(
 		dumpEditMethodsID,        // id that the layout said we could use
 		0,                      // no, we don't have a sub menu.
@@ -143,7 +146,7 @@ static void LoadBindings_registerMethod ()
 	
 	// add menu item
 	saveBindingID = pFact->addNewMenuAfter("Main",NULL,dumpEditMethodsID,EV_MLF_Normal);
-	pFact->addNewLabel(NULL,saveBindingID,szSaveBinding, NULL);
+	pFact->addNewLabel(NULL,saveBindingID,szSaveBinding,szSaveBindingStatus);
 	EV_Menu_Action* mySaveBindingAction = new EV_Menu_Action(
 		saveBindingID,          // id that the layout said we could use
 		0,                      // no, we don't have a sub menu.
@@ -199,27 +202,22 @@ static void LoadBindings_RemoveFromMethods ()
 //      Abiword Plugin Interface 
 // -----------------------------------------------------------------------
 
-static void LoadKeybindings( const char* basedir )
+static void LoadKeybindings(const char* uri)
 {
-	if (basedir) {
-		std::string userFile = basedir;
-		userFile += "/keybindings.xml";
+	UT_return_if_fail(uri);
+	UT_DEBUGMSG(("[LoadBindings] trying file %s\n", uri));
 		
-		UT_DEBUGMSG(("[LoadBindings] trying file %s\n", userFile.c_str()));
-		
-		// find out if the file exists at all
-		GsfInput* in = NULL;
-		struct stat buf;
-		if (stat(userFile.c_str(), &buf)==0 ||
-			(in = UT_go_file_open( userFile.c_str(), NULL ))) 
-		{
-			// it seems to exist, cleanup after ourselves ...
-			if (in) g_object_unref(G_OBJECT(in));
-			// ... and let LoadBindings_invoke do its thing
-			UT_DEBUGMSG(("[LoadBindings] invoking loader on %s\n", userFile.c_str()));
-			EV_EditMethodCallData userFileData( userFile.c_str(), UT_uint32(userFile.size()) );
-			LoadBindingsFromURI_invoke( NULL, &userFileData );
-		}
+	// find out if the file exists at all
+	GsfInput* in = NULL;
+	if (in = UT_go_file_open(uri, NULL)) 
+	{
+		// it seems to exist, cleanup after ourselves ...
+		if (in)
+			g_object_unref(G_OBJECT(in));
+		// ... and let LoadBindings_invoke do its thing
+		UT_DEBUGMSG(("[LoadBindings] invoking loader on %s\n", uri));
+		EV_EditMethodCallData userFileData(uri, strlen(uri));
+		LoadBindingsFromURI_invoke(NULL, &userFileData);
 	}
 }
 
@@ -235,11 +233,26 @@ ABI_FAR_CALL int abi_plugin_register (XAP_ModuleInfo * mi)
 
 	LoadBindings_registerMethod ();
 	
-	// execute the keybindings.xml file from the application directory, if present
-	LoadKeybindings( XAP_App::getApp()->getAbiSuiteAppDir() );
+	// load the keybindings.xml file from the application directory, if present
+	UT_UTF8String appFile = XAP_App::getApp()->getAbiSuiteAppDir();
+	appFile += "/keybindings.xml";
+	char * appUri = UT_go_filename_to_uri(appFile.utf8_str());
+	if (appUri)
+	{
+		LoadKeybindings(appUri);
+		FREEP(appUri);
+	}
 	
-	// execute the keybindings.xml file from the user's home directory, if present
-	LoadKeybindings( XAP_App::getApp()->getUserPrivateDirectory() );
+	// load the keybindings.xml file from the user's home directory, if present
+	UT_UTF8String userFile = XAP_App::getApp()->getUserPrivateDirectory();
+	userFile += "/keybindings.xml";
+	char * userUri = UT_go_filename_to_uri(userFile.utf8_str());
+	if (userUri)
+	{
+		LoadKeybindings(userUri);
+		FREEP(userUri);
+	}
+
 	return 1;
 }
 
