@@ -34,7 +34,7 @@ enum {
 	DONT_UNBIND_MOUSECONTEXTS	= 0x01,
 	DONT_UNBIND_KEYSTROKES		= 0x02,
 		
-	DONT_UNBIND_ANYTHING		= 0x03,
+	DONT_UNBIND_ANYTHING		= 0x03
 };
 
 enum _FROM_URI { FROM_URI };
