@@ -79,6 +79,7 @@ Presentation myPresentation;
 EV_EditMouseContext PresentationContextID =  EV_EMC_EMBED;
 static XAP_Menu_Id presentationID;
 static const char * szPresentation = "Presentation";
+static const char * szPresentationStatus = "View the document in presentation mode";
 static const char * szNextSlide = "Next Slide";
 static const char * szPrevSlide = "Previous Slide";
 static XAP_Menu_Id nextSlideID;
@@ -156,7 +157,7 @@ Presentation_registerMethod ()
     UT_DEBUGMSG(("presentationID %d \n",presentationID));
 
 
-    pFact->addNewLabel(NULL,presentationID,szPresentation, NULL);
+    pFact->addNewLabel(NULL,presentationID,szPresentation,szPresentationStatus);
 
     // Create the Action that will be called.
     EV_Menu_Action* myPresentationAction = new EV_Menu_Action(
@@ -346,6 +347,7 @@ Presentation_context (AV_View * v, EV_EditMethodCallData * d)
 		return false;
 	bool res = pFrame->runModalContextMenu(pView,szContextMenuName,
 									   xPos,yPos);
+	pFrame->nullUpdate();
 	GR_Graphics * pG  = pView->getGraphics();
 	if(pG && pG->getCaret())
 	  pG->getCaret()->disable();
@@ -414,17 +416,15 @@ bool Presentation::_loadPresentationBindings(AV_View * pView)
   {
       return true;
   }
-  // get a handle to the actual EditMethod
-  UT_String sAll;
-  UT_sint32 i =0 ;
-  while(sPresBindings[i].size() > 0)
-    {
-      sAll += sPresBindings[i];
-      i++;
-    }
-  EV_EditMethod * pLoadB = pEMC->findEditMethodByName ("LoadBindings_invoke");
+  // get the path where our app data is located
+  XAP_App * pApp = static_cast<XAP_App*>(XAP_App::getApp());
+  UT_String data_path( pApp->getAbiSuiteLibDir() );
+  data_path += G_DIR_SEPARATOR;
+  data_path += "Presentation.xml";
+
+  EV_EditMethod * pLoadB = pEMC->findEditMethodByName ("com.abisource.abiword.loadbindings.fromURI");
   g_return_val_if_fail (pLoadB != 0, false);
-  EV_EditMethodCallData calldata(sAll.c_str(),sAll.size());
+  EV_EditMethodCallData calldata(data_path.c_str(),data_path.size());
   calldata.m_xPos = 0;
   calldata.m_yPos = 0;
   return (pLoadB->Fn(pView,&calldata) ? TRUE : FALSE);
@@ -438,7 +438,7 @@ bool Presentation::start(AV_View * view)
   m_sPrevBindings = m_pApp->getInputMode();
   _loadPresentationBindings(view);
   UT_sint32 i = m_pApp->setInputMode("Presentation");
-  if(i <=0 )
+  if(i < 0 )
     return false;
   // get a handle to the actual EditMethod
   EV_EditMethod * pFullScreen = pEMC->findEditMethodByName ("viewFullScreen");
