@@ -349,11 +349,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
       // create a new sniffer
       m_sniffer = new IE_RSVGGraphic_Sniffer ();
 	}
-    else
-	{
-		// else just reference the one we've got
-		m_sniffer->ref();
-	}
 
     IE_ImpGraphic::registerImporter ( m_sniffer );
 
@@ -372,9 +367,7 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
     if ( m_sniffer )
 	{
 		IE_ImpGraphic::unregisterImporter ( m_sniffer );
-	}
-    if (!m_sniffer->unref())
-    {
+		delete m_sniffer;
 		m_sniffer = 0;
 	}
 
