@@ -31,27 +31,27 @@
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-infile-msole.h>
+#include <libwpd/WPXStream.h>
 #include "xap_Module.h"
 
 using libwpg::WPGraphics;
-using libwpg::WPGInputStream;
 using libwpg::WPGString;
 
 ABI_PLUGIN_DECLARE("WPG")
 
-class AbiWordPerfectGraphicsInputStream : public WPGInputStream
+class AbiWordPerfectGraphicsInputStream : public WPXInputStream
 {
 public:
 	AbiWordPerfectGraphicsInputStream(GsfInput *input);
 	~AbiWordPerfectGraphicsInputStream();
 
-	virtual unsigned char getc();
-	virtual bool isOle();
-	virtual WPGInputStream * getWPGOleStream();
-	virtual long read(long n, char* buffer);
-	virtual void seek(long offset);
+	virtual bool isOLEStream();
+	virtual WPXInputStream * getDocumentOLEStream();
+	virtual WPXInputStream * getDocumentOLEStream(const char * name);
+	virtual const uint8_t *read(size_t numBytes, size_t &numBytesRead);
+	virtual int seek(long offset, WPX_SEEK_TYPE seekType);
 	virtual long tell();
-	virtual bool atEnd();
+	virtual bool atEOS();
 
 private:
 
@@ -60,7 +60,7 @@ private:
 };
 
 AbiWordPerfectGraphicsInputStream::AbiWordPerfectGraphicsInputStream(GsfInput *input) :
-	WPGInputStream(),
+	WPXInputStream(true),
 	m_input(input),
 	m_ole(NULL)
 {
@@ -75,26 +75,35 @@ AbiWordPerfectGraphicsInputStream::~AbiWordPerfectGraphicsInputStream()
 	g_object_unref(G_OBJECT(m_input));
 }
 
-unsigned char AbiWordPerfectGraphicsInputStream::getc()
+const uint8_t * AbiWordPerfectGraphicsInputStream::read(size_t numBytes, size_t &numBytesRead)
 {
-	char buf[1];
-	if (0 == read(1, buf))
-		return (unsigned char)EOF;
-	return buf[0];
+	const uint8_t *buf = gsf_input_read(m_input, numBytes, NULL);
+
+	if (buf == NULL)
+		numBytesRead = 0;
+	else
+		numBytesRead = numBytes;
+
+	return buf;
 }
 
-long AbiWordPerfectGraphicsInputStream::read(long n, char* buffer)
+int AbiWordPerfectGraphicsInputStream::seek(long offset, WPX_SEEK_TYPE seekType) 
 {
-	const uint8_t *buf = gsf_input_read(m_input, n, (guint8*)buffer);
-	return buf == NULL ? 0 : n;
+	GSeekType gsfSeekType;
+	switch(seekType)
+	{
+	case WPX_SEEK_CUR:
+		gsfSeekType = G_SEEK_CUR;
+		break;
+	case WPX_SEEK_SET:
+		gsfSeekType = G_SEEK_SET;
+		break;
+	}
+
+	return gsf_input_seek(m_input, offset, gsfSeekType);
 }
 
-void AbiWordPerfectGraphicsInputStream::seek(long offset) 
-{
-	gsf_input_seek(m_input, offset, G_SEEK_SET);
-}
-
-bool AbiWordPerfectGraphicsInputStream::isOle()
+bool AbiWordPerfectGraphicsInputStream::isOLEStream()
 {
 	if (!m_ole)
 		m_ole = GSF_INFILE(gsf_infile_msole_new (m_input, NULL)); 
@@ -105,24 +114,29 @@ bool AbiWordPerfectGraphicsInputStream::isOle()
 	return false;
 }
 
-WPGInputStream * AbiWordPerfectGraphicsInputStream::getWPGOleStream()
+WPXInputStream * AbiWordPerfectGraphicsInputStream::getDocumentOLEStream()
 {
-	WPGInputStream *graphicsStream = NULL;
+	return getDocumentOLEStream("PerfectOffice_MAIN");
+}
+
+WPXInputStream * AbiWordPerfectGraphicsInputStream::getDocumentOLEStream(const char * name)
+{
+	WPXInputStream *documentStream = NULL;
 	
 	if (!m_ole)
 		m_ole = GSF_INFILE(gsf_infile_msole_new (m_input, NULL)); 
 	
 	if (m_ole)
-	{
-		GsfInput *child = gsf_infile_child_by_name(m_ole, "PerfectOffice_MAIN");
-		if (child) 
 		{
-			graphicsStream = new AbiWordPerfectGraphicsInputStream(child);
-			g_object_unref(G_OBJECT (child)); // the only reference should be encapsulated within the new stream
+			GsfInput *document = gsf_infile_child_by_name(m_ole, name);
+			if (document) 
+				{
+					documentStream = new AbiWordPerfectGraphicsInputStream(document);
+					g_object_unref(G_OBJECT (document)); // the only reference should be encapsulated within the new stream
+				}
 		}
-	}
 	
-	return graphicsStream;
+	return documentStream;
 }
 
 long AbiWordPerfectGraphicsInputStream::tell()
@@ -130,12 +144,11 @@ long AbiWordPerfectGraphicsInputStream::tell()
 	return gsf_input_tell(m_input);
 }
 
-bool AbiWordPerfectGraphicsInputStream::atEnd()
+bool AbiWordPerfectGraphicsInputStream::atEOS()
 {
 	return gsf_input_eof(m_input);
 }
 
-
 static IE_Imp_WordPerfectGraphics_Sniffer * m_ImpSniffer = 0;
 
 ABI_FAR_CALL
@@ -145,10 +158,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	{
 		m_ImpSniffer = new IE_Imp_WordPerfectGraphics_Sniffer ();
 	}
-	else
-	{
-		m_ImpSniffer->ref();
-	}
 
 	UT_ASSERT (m_ImpSniffer);
 
@@ -174,11 +183,8 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
 	UT_ASSERT (m_ImpSniffer);
 
 	IE_ImpGraphic::unregisterImporter (m_ImpSniffer);
-	
-	if (!m_ImpSniffer->unref())
-	{
-		m_ImpSniffer = 0;
-	}
+	delete m_ImpSniffer;
+	m_ImpSniffer = 0;
 	
 	return 1;
 }
