@@ -1,4 +1,4 @@
-/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+/* -*- Mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
 
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
@@ -29,6 +29,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "ut_stack.h"
 #include "ut_debugmsg.h"
 #include "ut_string.h"
 #include "ut_bytebuf.h"
@@ -177,12 +178,82 @@ static bool _convertLettersToSymbols(char c, const char *& subst);
 
 #define BULLET_LIST	1
 #define NUMBERED_LIST	2
+typedef int LIST_TYPE;
+
+class LaTeX_Analysis_Listener : public PL_Listener
+{
+public:
+	bool m_hasEndnotes;
+
+	LaTeX_Analysis_Listener(PD_Document * pDocument,
+							IE_Exp_LaTeX * pie)
+		: m_hasEndnotes(false)
+	{
+	}
+
+	virtual ~LaTeX_Analysis_Listener()
+	{
+	}
+
+	virtual bool		populate(PL_StruxFmtHandle sfh,
+								 const PX_ChangeRecord * pcr)
+	{
+		return true;	
+	}
+
+	virtual bool		populateStrux(PL_StruxDocHandle sdh,
+									  const PX_ChangeRecord * pcr,
+									  PL_StruxFmtHandle * psfh)
+	{
+		UT_ASSERT(pcr->getType() == PX_ChangeRecord::PXT_InsertStrux);
+		const PX_ChangeRecord_Strux * pcrx = static_cast<const PX_ChangeRecord_Strux *> (pcr);
+		*psfh = 0;							// we don't need it.
+
+		switch (pcrx->getStruxType())
+			{
+			case PTX_SectionEndnote:
+			case PTX_EndEndnote:
+				m_hasEndnotes = true;
+				break;
+			default:
+				break;
+			}
+
+		return true;
+	}
+
+	virtual bool		change(PL_StruxFmtHandle sfh,
+							   const PX_ChangeRecord * pcr)
+	{
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		return false;
+	}
+
+	virtual bool		insertStrux(PL_StruxFmtHandle sfh,
+									const PX_ChangeRecord * pcr,
+									PL_StruxDocHandle sdh,
+									PL_ListenerId lid,
+									void (* pfnBindHandles)(PL_StruxDocHandle sdhNew,
+															PL_ListenerId lid,
+															PL_StruxFmtHandle sfhNew))
+	{
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		return false;
+	}
+
+	virtual bool		signal(UT_uint32 iSignal)
+	{
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		return false;
+	}
+};
 
 class s_LaTeX_Listener : public PL_Listener
 {
 public:
 	s_LaTeX_Listener(PD_Document * pDocument,
-						IE_Exp_LaTeX * pie);
+					 IE_Exp_LaTeX * pie,
+					 LaTeX_Analysis_Listener& analysis);
 	virtual ~s_LaTeX_Listener();
 
 	virtual bool		populate(PL_StruxFmtHandle sfh,
@@ -212,6 +283,8 @@ protected:
 	void				_closeSection(void);
 	void				_closeSpan(void);
 	void				_closeTable(void);
+	void                _closeList(void);
+	void                _closeLists(void);
 	void				_openCell(PT_AttrPropIndex api);
 	void				_openParagraph(PT_AttrPropIndex api);
 	void				_openSection(PT_AttrPropIndex api);
@@ -238,12 +311,17 @@ protected:
 	bool           m_bInSymbol;
  	bool	m_bInCourier;
  	bool	m_bInSansSerif;
+	bool				m_bInEndnote;
+	bool				m_bHaveEndnote;
   
 	JustificationTypes  m_eJustification;
 	bool				m_bLineHeight;
 	bool				m_bFirstSection;
 	int 				ChapterNumber;
-	int				list_type;
+	int                 m_Indent;
+	
+// Type for the last-processed list  
+	LIST_TYPE			list_type;
 
 	// Need to look up proper type, and place to stick #defines...
 
@@ -253,14 +331,40 @@ protected:
 	// Table utility members
 	
 	ie_Table *			m_pTableHelper;
+
+//	std::stack<LIST_TYPE>   list_stack;
+	UT_NumberStack          list_stack;
 };
 
 void s_LaTeX_Listener::_closeParagraph(void)
 {
-	if ((!m_bInCell) && (!m_bInFootnote)) m_pie->write("\n");
+	if ((!m_bInCell) && (!m_bInFootnote) && (!m_bInEndnote)) m_pie->write("\n");
 	m_bInHeading = false;
 	return;
 }
+        
+void s_LaTeX_Listener::_closeList(void)
+{
+	switch (list_type) {
+		case NUMBERED_LIST:
+			m_pie->write("\\end{enumerate}\n");
+			break;
+		case BULLET_LIST:
+			m_pie->write("\\end{itemize}\n");
+			break;
+		default:
+			;
+	}
+	list_stack.pop();
+}
+
+void s_LaTeX_Listener::_closeLists()
+{
+	do{
+		_closeList();
+	} while(list_stack.getDepth());
+	m_bInList = false;
+}
 
 void s_LaTeX_Listener::_closeSection(void)
 {
@@ -271,12 +375,7 @@ void s_LaTeX_Listener::_closeSection(void)
 
 	if (m_bInList)
 	{
-		m_bInList = false;
-		if (list_type == BULLET_LIST)
-			m_pie->write("\\end{itemize}");
-		else if (list_type == NUMBERED_LIST)
-			m_pie->write("\\end{enumerate}");
-
+		this->_closeLists();
 	}
  
 	if (m_bMultiCols)
@@ -291,7 +390,7 @@ void s_LaTeX_Listener::_closeSection(void)
 
 void s_LaTeX_Listener::_closeBlock(void)
 { 
-	if(m_bInFootnote)
+	if(m_bInFootnote || m_bInEndnote)
 		return;
 	if (!m_bInBlock)
 		return;
@@ -383,41 +482,75 @@ void s_LaTeX_Listener::_openParagraph(PT_AttrPropIndex api)
 			&& (pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue))
 			&& (0 == strcmp(szValue, "Normal")))
 		{
-			if (m_bInList)
-				m_pie->write("\\item ");
-			else
+			int indent = 0;
+			bool bNewList = false;
+			const gchar * szIndent, * szLeft, * szListStyle;
+			
+			pAP->getProperty("list-style", szListStyle);
+			
+			if (pAP->getProperty("text-indent", szIndent) && pAP->getProperty("margin-left", szLeft))
+			{
+				indent = UT_convertToDimension(szIndent, DIM_MM) + UT_convertToDimension(szLeft, DIM_MM);
+				if (m_bInList)
+				{
+					UT_DEBUGMSG(("      indent = %d, m_Indent = %d\n", indent, m_Indent));
+					if(indent > this->m_Indent) //nested list
+						bNewList = true;
+					else if (indent < this->m_Indent)
+					{
+						this->_closeList();
+					}
+					else
+						/*
+						 * now we have indent == this->m_Indent,
+						 * but it is possible that the current list item is
+						 * of different style with the last one.
+						 */                                    
+					{
+						if(szListStyle)
+						{
+							LIST_TYPE temp = BULLET_LIST;
+							if (0 == strcmp(szListStyle, "Numbered List") )
+								temp = NUMBERED_LIST;
+							if (temp != list_type)
+							{
+								this->_closeList();
+								bNewList = true;
+							}
+						}
+					}
+				}
+			}
+			
+			if (bNewList || !m_bInList) 
+				//necessary to build a new (possibly nested) list
 			{
 				if (pAP->getProperty("list-style", szValue))
 				{
+					//if(NULL == list_stack)
+					//  this->list_stack = new std::stack<LIST_TYPE>();
 					if (0 == strcmp(szValue, "Numbered List"))
 					{
 						list_type = NUMBERED_LIST;
-						m_pie->write("\\begin{enumerate}\n\\item ");
+						m_pie->write("\\begin{enumerate}\n");
 					}
 					else if (0 == strcmp(szValue, "Bullet List"))
 					{
 						list_type = BULLET_LIST;
-						m_pie->write("\\begin{itemize}\n\\item ");
+						m_pie->write("\\begin{itemize}\n");
 					}
+					list_stack.push(list_type);
 				}
 				m_bInList = true;
 			}
+			
+			if (szIndent && szLeft)
+				this->m_Indent = indent;
+			
+			m_pie->write("\\item ");
 		} else if (m_bInList) {
-			m_bInList = false;
-			switch (list_type) {
-			case NUMBERED_LIST:
-				m_pie->write("\\end{enumerate}\n");
-				break;
-			case BULLET_LIST:
-				m_pie->write("\\end{itemize}\n");
-				break;
-			default:
-				;
-			}
+			this->_closeLists();
 		}
-
-
-
 		if (pAP->getAttribute(PT_STYLE_ATTRIBUTE_NAME, szValue))
 		{
 			if (strstr(szValue, "Heading"))
@@ -824,9 +957,8 @@ void s_LaTeX_Listener::_openSpan(PT_AttrPropIndex api)
 void s_LaTeX_Listener::_openTable(PT_AttrPropIndex api)
 {
 	UT_sint32 i = 0;
-	
-	m_pie->write("\n\\\\");
-	m_pie->write("\n%");
+
+	m_pie->write("\n\n%");
 	m_pie->write("\n% Table begins");
 	m_pie->write("\n% ");
 	m_pie->write("\n\\begin{table}[h]\\begin{tabular}{|");
@@ -1194,7 +1326,7 @@ static bool _convertLettersToSymbols(char c, const char *& subst)
 	}
 }
 
-s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie)
+s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie, LaTeX_Analysis_Listener& analysis)
   : m_pDocument(pDocument),
 	m_pie(pie),
 	m_bInBlock(false),
@@ -1205,7 +1337,9 @@ s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie)
 	m_bInSymbol(0),
 	m_bInCourier(0),
 	m_bInSansSerif(0),
-	m_bFirstSection(true)
+	m_bFirstSection(true),
+	m_bInEndnote(false),
+	m_bHaveEndnote(analysis.m_hasEndnotes)
 {
 	m_pie->write("%% ================================================================================\n");
 	m_pie->write("%% This LaTeX file was created by AbiWord.                                         \n");
@@ -1234,6 +1368,10 @@ s_LaTeX_Listener::s_LaTeX_Listener(PD_Document * pDocument, IE_Exp_LaTeX * pie)
 	m_pie->write("%% Please set your language here\n");
 	m_pie->write("\\usepackage[english]{babel}\n");
 	m_pie->write("\\usepackage{color}\n");
+
+	if (m_bHaveEndnote)
+		m_pie->write("\\usepackage{endnotes}\n");
+
 	// Must be as late as possible.
 	m_pie->write("\\usepackage{hyperref}\n");
 
@@ -1259,7 +1397,8 @@ s_LaTeX_Listener::~s_LaTeX_Listener()
 	_closeSection();
 	_handleDataItems();
 	DELETEP(m_pTableHelper);
-
+	if (m_bHaveEndnote)
+		m_pie->write("\n\\theendnotes");
 	m_pie->write("\n\\end{document}\n");
 }
 
@@ -1389,7 +1528,6 @@ bool s_LaTeX_Listener::populateStrux(PL_StruxDocHandle sdh,
 
 	switch (pcrx->getStruxType())
 	{
-	case PTX_SectionEndnote:
 	case PTX_Section:
 	{
 		_closeSpan();
@@ -1508,8 +1646,31 @@ bool s_LaTeX_Listener::populateStrux(PL_StruxDocHandle sdh,
 		m_pie->write("\\footnote{");
 		return true;
 	}
-
+	
+	case PTX_SectionTOC:
+	{
+		_closeSpan();	
+		_closeBlock();
+		/*
+		_closeSection();
+		 */
+		m_pie->write("\\tableofcontents \n");
+	}
+	case PTX_EndTOC:
+		return true;
+	
+	case PTX_SectionEndnote:
+	{
+		m_bInEndnote = true;
+		m_pie->write("\\endnote{");
+		return true;
+	}
 	case PTX_EndEndnote:
+	{
+		m_bInEndnote = false;
+		m_pie->write("} ");
+		return true;
+	}
 	default:
 		UT_ASSERT(UT_TODO);
 		return true;
@@ -1547,7 +1708,11 @@ bool s_LaTeX_Listener::signal(UT_uint32 /* iSignal */)
 
 UT_Error IE_Exp_LaTeX::_writeDocument(void)
 {
-	m_pListener = new s_LaTeX_Listener(getDoc(),this);
+	LaTeX_Analysis_Listener analysis(getDoc(), this);
+	if (!getDoc()->tellListener(&analysis))
+		return UT_ERROR;
+
+	m_pListener = new s_LaTeX_Listener(getDoc(),this, analysis);
 	if (!m_pListener)
 		return UT_IE_NOMEMORY;
 	if (!getDoc()->tellListener(static_cast<PL_Listener *>(m_pListener)))
@@ -2329,22 +2494,22 @@ static int wvConvertUnicodeToLaTeX(U16 char16,const char*& out)
 			return(1);
 
 		case 0x01FA:
-			printf("\\'{\\AA}");  /*  with acute */
+			printf("\\'{\\AA}");  /* ? with acute */
 			return(1);
 		case 0x01FB:
-			printf("\\'{\\aa}");  /*  with acute */
+			printf("\\'{\\aa}");  /* ? with acute */
 			return(1);
 		case 0x01FC:
-			printf("\\'{\\AE}");  /*  with acute */
+			printf("\\'{\\AE}");  /* ? with acute */
 			return(1);
 		case 0x01FD:
-			printf("\\'{\\ae}");  /*  with acute */
+			printf("\\'{\\ae}");  /* ? with acute */
 			return(1);
 		case 0x01FE:
-			printf("\\'{\\O}");  /*  with acute */
+			printf("\\'{\\O}");  /* ? with acute */
 			return(1);
 		case 0x01FF:
-			printf("\\'{\\o}");  /*  with acute */
+			printf("\\'{\\o}");  /* ? with acute */
 			return(1);
 
 		case 0x2010:
