@@ -38,7 +38,7 @@ typedef struct wri_struct {
     char	*data;
     short	size;	/* in bytes */
     short	type;
-    char	*name;	
+    const char	*name;	
 } wri_struct;
 
 #define	CT_IGNORE	0
